﻿using System;

using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ServiceModel;
using Traducteur.WEBApiTranslator;
 
namespace Traducteur
{
    public class TraducteurEventArgs :EventArgs
    {
        public String Resultat;
        public Boolean EstSynthetiser;
        public TraducteurEventArgs(String r, Boolean s)
        {
            Resultat = r;
            EstSynthetiser = s;
        }
    }

    public class APITranslator
    {
        //Pour obtenir la clé http://www.bing.com/developers/createapp.aspx
        const String APPID = "<COPIEZ VOTRE CLE ICI>";
        //Variable du Service 
        private LanguageServiceClient _clientTranslator;

        public delegate void TraducteurHandler(Object sender,TraducteurEventArgs e);
        public event TraducteurHandler RequeteTerminee;
        protected void SurRequeteTerminee(TraducteurEventArgs e)
        {
            if (RequeteTerminee != null)
            {
                RequeteTerminee(this, e);
            }
        }
        
        
        
        public APITranslator()
        {
            //Ici nous codons en dur le binding ainsi que le endPoint
            //pour éviter l'utilisation de fichier de configuration dans les clients
            BasicHttpBinding basicBinding = new BasicHttpBinding(BasicHttpSecurityMode.None);

            EndpointAddress endPoint = new EndpointAddress("http://api.microsofttranslator.com/v2/soap.svc");
            _clientTranslator = new LanguageServiceClient(basicBinding,endPoint);
            _clientTranslator.TranslateCompleted += new EventHandler<TranslateCompletedEventArgs>(_clientTranslator_TranslateCompleted);
            _clientTranslator.SpeakCompleted += new EventHandler<SpeakCompletedEventArgs>(_clientTranslator_SpeakCompleted);
       
        }

       

        void _clientTranslator_SpeakCompleted(object sender, SpeakCompletedEventArgs e)
        {
            String Resultat = String.Empty;
            if (e.Cancelled)
            {
                Resultat = "Requête annulée";
                TraducteurEventArgs args = new TraducteurEventArgs(Resultat, false);
                RequeteTerminee(this, args);
            }
            if (e.Error != null)
            {
                //Retourne le message d'erreur au client
                Resultat = e.Error.Message;
                TraducteurEventArgs args = new TraducteurEventArgs(Resultat, false);
                RequeteTerminee(this, args);
            }
            else
            {
                Resultat = e.Result;
                TraducteurEventArgs args = new TraducteurEventArgs(Resultat, true);
                RequeteTerminee(this, args);
            }  
        }

        

        void _clientTranslator_TranslateCompleted(object sender, TranslateCompletedEventArgs e)
        {
            String Resultat=String.Empty;
            if (e.Cancelled)
            {
                Resultat = "Requête annulée";                
            }
            if (e.Error != null)
            {
                //Retourne le message d'erreur au client
                Resultat = e.Error.Message;
            }
            else
            {
                Resultat = e.Result;
                
            }
            TraducteurEventArgs args = new TraducteurEventArgs(Resultat, false);
            RequeteTerminee(this, args);
        }
        /// <summary>
        /// Appel l'API TranslateAsync
        /// </summary>
        /// <param name="texte">texte à traduire</param>
        /// <param name="de">Langage source</param>
        /// <param name="vers">langage déstination</param>
        public void Traduire(String texte, String de, String vers)
        {
            _clientTranslator.TranslateAsync(APPID, texte, de, vers); 
        }

        public void Synthetiser(String texte, String langage)
        {
            _clientTranslator.SpeakAsync(APPID ,texte,langage,"audio/wav"); 
        }
    }
}
